[−][src]Enum unicode_types::latin_extended_e::LatinExtendedE
An enum to represent all characters in the LatinExtendedE block.
Variants
LatinSmallLetterBarredAlpha\u{ab30}: 'ꬰ'
LatinSmallLetterAReversedDashSchwa\u{ab31}: 'ꬱ'
LatinSmallLetterBlackletterE\u{ab32}: 'ꬲ'
LatinSmallLetterBarredE\u{ab33}: 'ꬳ'
LatinSmallLetterEWithFlourish\u{ab34}: 'ꬴ'
LatinSmallLetterLenisF\u{ab35}: 'ꬵ'
LatinSmallLetterScriptGWithCrossedDashTail\u{ab36}: 'ꬶ'
LatinSmallLetterLWithInvertedLazyS\u{ab37}: 'ꬷ'
LatinSmallLetterLWithDoubleMiddleTilde\u{ab38}: 'ꬸ'
LatinSmallLetterLWithMiddleRing\u{ab39}: 'ꬹ'
LatinSmallLetterMWithCrossedDashTail\u{ab3a}: 'ꬺ'
LatinSmallLetterNWithCrossedDashTail\u{ab3b}: 'ꬻ'
LatinSmallLetterEngWithCrossedDashTail\u{ab3c}: 'ꬼ'
LatinSmallLetterBlackletterO\u{ab3d}: 'ꬽ'
LatinSmallLetterBlackletterOWithStroke\u{ab3e}: 'ꬾ'
LatinSmallLetterOpenOWithStroke\u{ab3f}: 'ꬿ'
LatinSmallLetterInvertedOe\u{ab40}: 'ꭀ'
LatinSmallLetterTurnedOeWithStroke\u{ab41}: 'ꭁ'
LatinSmallLetterTurnedOeWithHorizontalStroke\u{ab42}: 'ꭂ'
LatinSmallLetterTurnedOOpenDashO\u{ab43}: 'ꭃ'
LatinSmallLetterTurnedOOpenDashOWithStroke\u{ab44}: 'ꭄ'
LatinSmallLetterStirrupR\u{ab45}: 'ꭅ'
LatinLetterSmallCapitalRWithRightLeg\u{ab46}: 'ꭆ'
LatinSmallLetterRWithoutHandle\u{ab47}: 'ꭇ'
LatinSmallLetterDoubleR\u{ab48}: 'ꭈ'
LatinSmallLetterRWithCrossedDashTail\u{ab49}: 'ꭉ'
LatinSmallLetterDoubleRWithCrossedDashTail\u{ab4a}: 'ꭊ'
LatinSmallLetterScriptR\u{ab4b}: 'ꭋ'
LatinSmallLetterScriptRWithRing\u{ab4c}: 'ꭌ'
LatinSmallLetterBaselineEsh\u{ab4d}: 'ꭍ'
LatinSmallLetterUWithShortRightLeg\u{ab4e}: 'ꭎ'
LatinSmallLetterUBarWithShortRightLeg\u{ab4f}: 'ꭏ'
LatinSmallLetterUi\u{ab50}: 'ꭐ'
LatinSmallLetterTurnedUi\u{ab51}: 'ꭑ'
LatinSmallLetterUWithLeftHook\u{ab52}: 'ꭒ'
LatinSmallLetterChi\u{ab53}: 'ꭓ'
LatinSmallLetterChiWithLowRightRing\u{ab54}: 'ꭔ'
LatinSmallLetterChiWithLowLeftSerif\u{ab55}: 'ꭕ'
LatinSmallLetterXWithLowRightRing\u{ab56}: 'ꭖ'
LatinSmallLetterXWithLongLeftLeg\u{ab57}: 'ꭗ'
LatinSmallLetterXWithLongLeftLegAndLowRightRing\u{ab58}: 'ꭘ'
LatinSmallLetterXWithLongLeftLegWithSerif\u{ab59}: 'ꭙ'
LatinSmallLetterYWithShortRightLeg\u{ab5a}: 'ꭚ'
ModifierBreveWithInvertedBreve\u{ab5b}: '꭛'
ModifierLetterSmallHeng\u{ab5c}: 'ꭜ'
ModifierLetterSmallLWithInvertedLazyS\u{ab5d}: 'ꭝ'
ModifierLetterSmallLWithMiddleTilde\u{ab5e}: 'ꭞ'
ModifierLetterSmallUWithLeftHook\u{ab5f}: 'ꭟ'
LatinSmallLetterSakhaYat\u{ab60}: 'ꭠ'
LatinSmallLetterIotifiedE\u{ab61}: 'ꭡ'
LatinSmallLetterOpenOe\u{ab62}: 'ꭢ'
LatinSmallLetterUo\u{ab63}: 'ꭣ'
LatinSmallLetterInvertedAlpha\u{ab64}: 'ꭤ'
GreekLetterSmallCapitalOmega\u{ab65}: 'ꭥ'
LatinSmallLetterDzDigraphWithRetroflexHook\u{ab66}: 'ꭦ'
LatinSmallLetterTsDigraphWithRetroflexHook\u{ab67}: 'ꭧ'
Methods
impl LatinExtendedE[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case